import { Box, Button, Stack, TextField } from '@suid/material';
import { Component, createEffect, createSignal } from 'solid-js';
import { useI18n } from '@solid-primitives/i18n';

import Dialog from '../dialog';
import { peekCachedSignal } from '../../workers/cached-signals';
import dispatch from '../../workers/dispatcher-main';

interface Props {
  wptId: string;
  open: () => boolean;
  closeHandler?: () => vpod;
}

const WptEditDialog: Component<Props> = (props) => {
  const { wptId, closeHandler, open } = props;
  const [t, { add, locale, dict }] = useI18n();

  const wpt = peekCachedSignal({ id: wptId, method: 'getWpt' });
  const [editedWpt, setEditedWpt] = createSignal<Wpt>();

  createEffect(() => {
    console.log({
      caller: 'WptEditDialog / createEffect',
      wptId,
      wpt: wpt(),
    });
    setEditedWpt(wpt());
  });

  const _closeHandler = () => {
    if (!!closeHandler) {
      closeHandler();
    }
  };

  const saveHandler = () => {
    console.log({
      caller: 'WptEditDialog / saveHandler',
      wptId,
      editedWpt: editedWpt(),
    });
    dispatch({ action: 'putWpt', params: { id: wptId, wpt: editedWpt() } });
    _closeHandler();
  };

  const getTitle = () => {
    if (wpt()?.name) {
      return `${wpt()?.name} (${t('wpt')})`;
    }
    return t('wpt');
  };

  return (
    <Dialog
      open={open() && !!wpt()}
      title={getTitle()}
      closeHandler={_closeHandler}
    >
      <Box
        component='form'
        sx={{
          width: '100%',
          '& .MuiTextField-root': { m: 1, width: '100%' },
          paddingTop: '5px',
        }}
        noValidate
        autoComplete='off'
      >
        <div>
          <TextField
            required
            label={t('name')}
            defaultValue={wpt()?.name}
            onChange={(event: any, value: string) => {
              setEditedWpt({ ...editedWpt(), name: value });
            }}
          />
          <TextField
            label={t('sym')}
            defaultValue={wpt()?.sym}
            onChange={(event: any, value: string) => {
              setEditedWpt({ ...editedWpt(), sym: value });
            }}
          />
          <TextField
            label={t('minZoom')}
            defaultValue={wpt()?.extensions?.['dyo:minZoom']?.toString()}
            onChange={(event: any, value: string) => {
              const extensions = {
                ...editedWpt()?.extensions,
                'dyo:minZoom': parseFloat(value),
              };
              setEditedWpt({ ...editedWpt(), extensions });
            }}
          />
          <TextField
            label={t('gpxDesc')}
            type='text'
            rows={5}
            multiline={true}
            value={editedWpt()?.desc || ''}
            onChange={(event: any) => {
              setEditedWpt({ ...editedWpt(), desc: event.target.value });
            }}
            InputProps={{ inputComponent: 'textarea' }}
          />
          <Stack spacing={2} direction='row' sx={{ marginTop: '20px' }}>
            <Button variant='outlined' color='secondary' onClick={closeHandler}>
              {t('cancel')}
            </Button>
            <Button variant='contained' color='success' onClick={saveHandler}>
              {t('save')}
            </Button>
          </Stack>
        </div>
      </Box>
    </Dialog>
  );
};

export default WptEditDialog;
